@@ -1,4 +1,6 @@
 /*  xfce4-places-plugin
+ *
+ *  Interface to create user bookmark group.
  *
  *  Copyright (c) 2007 Diego Ongaro <ongardie@gmail.com>
  *
@@ -21,22 +23,9 @@
 #define _XFCE_PANEL_PLACES_MODEL_USER_H
 
 #include "model.h"
-#include "model_system.h"
-#include <glib.h>
 
-typedef struct _BookmarksUser BookmarksUser;
-
-BookmarksUser*
-places_bookmarks_user_init(const BookmarksSystem *system);
-
-void
-places_bookmarks_user_visit(BookmarksUser *b, BookmarksVisitor *visitor);
-
-gboolean
-places_bookmarks_user_changed(BookmarksUser *b);
-
-void
-places_bookmarks_user_finalize(BookmarksUser *b);
+PlacesBookmarkGroup*
+places_bookmarks_user_create(void);
 
 #endif
-// vim: ai et tabstop=4
+/* vim: set ai et tabstop=4: */
