@@ -1,4 +1,6 @@
 /*  xfce4-places-plugin
+ *
+ *  Interface to create volumes bookmark group.
  *
  *  Copyright (c) 2007 Diego Ongaro <ongardie@gmail.com>
  *
@@ -21,21 +23,9 @@
 #define _XFCE_PANEL_PLACES_MODEL_VOLUMES_H
 
 #include "model.h"
-#include <glib.h>
 
-typedef struct _BookmarksVolumes BookmarksVolumes;
-
-BookmarksVolumes*
-places_bookmarks_volumes_init();
-
-void
-places_bookmarks_volumes_visit(BookmarksVolumes *b, BookmarksVisitor *visitor);
-
-gboolean
-places_bookmarks_volumes_changed(BookmarksVolumes *b);
-
-void
-places_bookmarks_volumes_finalize(BookmarksVolumes *b);
+PlacesBookmarkGroup*
+places_bookmarks_volumes_create(gboolean mount_and_open_by_default);
 
 #endif
-// vim: ai et tabstop=4
+/* vim: set ai et tabstop=4: */
